<?xml version='1.0'?>
<!-- vim: sw=2 sta et
-->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:doc="http://nwalsh.com/xsl/documentation/1.0"
                xmlns:gt="http://docbook2x.sourceforge.net/xsl/gentext-title"
                exclude-result-prefixes="doc gt"
                version='1.0'
                xml:lang="en">

<!-- ********************************************************************
     $Id: synop.xsl,v 1.8 2004/08/07 15:36:32 stevecheng Exp $
     ********************************************************************

     (C) 2000-2004 Steve Cheng <stevecheng@users.sourceforge.net>

     This file is part of the docbook2X XSLT stylesheets for
     converting DocBook to man pages.

     See ../../COPYING for the copyright status of this software.

     ******************************************************************** -->

<doc:reference xmlns="">
<title>Synopses</title>
</doc:reference>

<!-- ==================================================================== -->

<xsl:template match="synopsis">
  <verbatim>
    <xsl:apply-templates />
  </verbatim>
</xsl:template>


<!-- ==================================================================== -->

<xsl:template match="cmdsynopsis">
  <para align="l">
    <xsl:choose>
      <xsl:when test="local-name(*[1]) = 'command'">
        <xsl:apply-templates select="*[1]" mode="cmdsynopsis" />
        <xsl:text> </xsl:text>
        <leftindent>
          <xsl:apply-templates select="*[position() > 1]" mode="cmdsynopsis" />
        </leftindent>
      </xsl:when>
  
      <xsl:otherwise>
        <xsl:apply-templates mode="cmdsynopsis" />
      </xsl:otherwise>
    </xsl:choose>
  </para>
</xsl:template>

<xsl:template match="*" mode="cmdsynopsis">
  <tt><xsl:value-of select="." /></tt>
</xsl:template>

<xsl:template match="sbr" mode="cmdsynopsis">
  <br />
</xsl:template>

<xsl:template match="command|option" mode="cmdsynopsis">
  <xsl:if test="preceding-sibling::*">
    <xsl:call-template name="cmdsynopsis-gentext-sepchar" />
  </xsl:if>

  <b><tt>
    <xsl:apply-templates mode="cmdsynopsis" />
  </tt></b>
</xsl:template>

<xsl:template match="replaceable" mode="cmdsynopsis">
  <xsl:if test="preceding-sibling::*">
    <xsl:call-template name="cmdsynopsis-gentext-sepchar" />
  </xsl:if>

  <b>
    <xsl:apply-templates mode="cmdsynopsis" />
  </b>
</xsl:template>

<xsl:template match="group|arg" mode="cmdsynopsis">
  <xsl:if test="preceding-sibling::* and not(parent::arg)">
    <xsl:call-template name="cmdsynopsis-gentext-sepchar" />
  </xsl:if>

  <xsl:call-template name="arg-gentext-choice-start" />
  <tt><xsl:apply-templates mode="cmdsynopsis" /></tt>
  <xsl:call-template name="arg-gentext-choice-end" />
  <xsl:call-template name="arg-gentext-rep" />
</xsl:template>

<!-- Member of groups -->

<xsl:template match="group/*" mode="cmdsynopsis" priority="2.0">
  <xsl:if test="position()>1">
    <xsl:call-template name="arg-gentext-or-separator" />
  </xsl:if>
  <xsl:apply-templates mode="cmdsynopsis" />
</xsl:template>

<xsl:template match="group/group" mode="cmdsynopsis" priority="2.5">
  <xsl:if test="position()>1">
    <xsl:call-template name="arg-gentext-or-separator" />
  </xsl:if>

  <xsl:call-template name="arg-gentext-choice-start" />
  <tt><xsl:apply-templates mode="cmdsynopsis" /></tt>
  <xsl:call-template name="arg-gentext-choice-end" />
  <xsl:call-template name="arg-gentext-rep" />
</xsl:template>

<xsl:template match="group/option" mode="cmdsynopsis" priority="2.5">
  <xsl:if test="position()>1">
    <xsl:choose>
      <xsl:when test="preceding-sibling::*[local-name(.) != 'option']
                      or following-sibling::*[local-name(.) != 'option']">
        <xsl:call-template name="arg-gentext-or-separator" />
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="arg-gentext-or-separator-nospace" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:if>

  <xsl:apply-templates mode="cmdsynopsis" />
  <xsl:call-template name="arg-gentext-rep" />
</xsl:template>

<xsl:template match="group/arg" mode="cmdsynopsis" priority="2.5">
  <xsl:if test="position()>1">
    <xsl:call-template name="arg-gentext-or-separator" />
  </xsl:if>

  <tt><xsl:apply-templates mode="cmdsynopsis" /></tt>
  <xsl:call-template name="arg-gentext-rep" />
</xsl:template>

<!-- ==================================================================== -->

<xsl:template match="funcsynopsis">
  <xsl:choose>
    <xsl:when test="funcdef"><!-- Old content model -->
      <xsl:apply-templates select="funcsynopsisinfo" mode="funcsynopsis" />
      <xsl:call-template name="funcprototype" />
    </xsl:when>
    <xsl:otherwise>
      <xsl:apply-templates mode="funcsynopsis" />
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="*" mode="funcsynopsis">
  <xsl:apply-templates select="." />
</xsl:template>

<xsl:template match="funcsynopsisinfo" mode="funcsynopsis">
  <verbatim>
    <xsl:apply-templates mode="funcsynopsis" />
  </verbatim>
  <sp length="1" />
</xsl:template>

<xsl:template match="funcprototype" name="funcprototype" mode="funcsynopsis">
  <para align="l">
    <tt>
      <xsl:apply-templates select="modifier[count(following-sibling::funcdef) &gt; 0]"
                           mode="funcsynopsis" />
      <xsl:apply-templates select="funcdef" mode="funcsynopsis" />
    </tt>
  
    <leftindent><tt>
      <xsl:text>(</xsl:text>
      <xsl:apply-templates select="void|varargs|paramdef|varargs"
                           mode="funcsynopsis" />
      <xsl:text>)</xsl:text>
    
      <xsl:apply-templates select="modifier[count(following-sibling::funcdef) = 0]"
                           mode="funcsynopsis" />

      <xsl:text>;</xsl:text>
    </tt></leftindent>
  </para>
</xsl:template>

<xsl:template match="modifier" mode="funcsynopsis">
  <xsl:apply-templates mode="funcsynopsis" />
</xsl:template>

<xsl:template match="funcdef" mode="funcsynopsis">
  <xsl:apply-templates mode="funcsynopsis" />
</xsl:template>

<xsl:template match="function" mode="funcsynopsis">
  <xsl:choose>
    <xsl:when test="$funcsynopsis-decoration">
      <i><xsl:apply-templates mode="funcsynopsis" /></i>
    </xsl:when>
    <xsl:otherwise>
      <xsl:apply-templates mode="funcsynopsis" />
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="void" mode="funcsynopsis">
  <xsl:text>void</xsl:text>
</xsl:template>

<xsl:template match="varargs" mode="funcsynopsis">
  <xsl:if test="preceding-sibling::paramdef">
    <xsl:text>, </xsl:text>
  </xsl:if>

  <xsl:text>...</xsl:text>
</xsl:template>

<xsl:template match="paramdef" mode="funcsynopsis">
  <xsl:if test="preceding-sibling::paramdef">
    <xsl:text>, </xsl:text>
  </xsl:if>
  
  <xsl:apply-templates mode="funcsynopsis" />
</xsl:template>

<xsl:template match="paramdef/parameter" mode="funcsynopsis">
  <xsl:choose>
    <xsl:when test="$funcsynopsis-decoration">
      <i><xsl:apply-templates mode="funcsynopsis" /></i>
    </xsl:when>
    <xsl:otherwise>
      <xsl:apply-templates mode="funcsynopsis" />
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="funcparams" mode="funcsynopsis">
  <xsl:text>(</xsl:text>
  <xsl:apply-templates mode="funcsynopsis" />
  <xsl:text>)</xsl:text>
</xsl:template>

<!-- ==================================================================== -->
<!-- FIXME: bring back classsynopsis stuff ! -->

</xsl:stylesheet>
